@@ -215,6 +215,7 @@ class ParameterOptimizeInfo:
         self.maxiter = maxiter
         self.has_solution_at_zero = False
         self.lambda_history = np.zeros(self.maxiter, dtype=np.double)
+        self.solutions = []
         self.stepsize_history = np.zeros(self.maxiter, dtype=np.double)
         self.solution_history = np.zeros(self.maxiter, dtype=np.bool)
         self.stable_history = np.zeros(self.maxiter, dtype=np.bool)
@@ -304,6 +305,19 @@ class ParameterOptimizeInfo:
         plt.title("Newton residuals in parameter optimization.")
         plt.legend(["n is target_n", "n is not target_n"])
 
+    def animate_solutions(self):
+        import matplotlib.animation as anim
+        fig, ax = self.solutions[0].plot()
+        lambdas = self.get_lambda()[self.get_found_solution()]
+        stable = self.get_is_stable()[self.get_found_solution()]
+        def _animate(i):
+            p_fig, p_ax = self.solutions[i].plot(fig=fig)
+            p_ax.set_title(f"lambda={np.round(lambdas[i], 5)}, is stable: {stable[i]}")
+            return [p_ax]
+        ani = anim.FuncAnimation(fig, _animate, frames=range(len(self.solutions)),
+                                 interval=1000, blit=False)
+        return ani
+
     def __str__(self):
         np.set_printoptions(linewidth=100000)
         out = "parameter optimize info:\n\t"
@@ -335,12 +349,14 @@ class ParameterOptimizeInfo:
         self.has_solution_at_zero = has_solution_at_zero
         return self
 
-    def _set(self, lambda_value, lambda_stepsize, found_solution, newton_iter_info, is_stable=False):
+    def _set(self, lambda_value, solution, lambda_stepsize, found_solution, newton_iter_info, is_stable=False):
         self.lambda_history[self._step] = lambda_value
         self.stepsize_history[self._step] = lambda_stepsize
         self.solution_history[self._step] = found_solution
         self.stable_history[self._step] = is_stable
         self.newton_iter_infos += [newton_iter_info]
+        if solution is not None:
+            self.solutions += [solution]
         self._step += 1
         return self
 
@@ -995,7 +1011,7 @@ class StaticConfiguration:
              face_quantity_cmap=None, face_quantity_clim=None, face_quantity_alpha=1,
              face_quantity_logarithmic_colors=False,
              vortex_diameter=0.25, vortex_color=(0, 0, 0), anti_vortex_color=(0.8, 0.1, 0.2),
-             vortex_alpha=1):
+             vortex_alpha=1, fig=None):
         """
         Visualize static configuration on circuit.
 
@@ -1024,7 +1040,7 @@ class StaticConfiguration:
             face_quantity_cmap=face_quantity_cmap, face_quantity_clim=face_quantity_clim,
             face_quantity_alpha=face_quantity_alpha,
             face_quantity_logarithmic_colors=face_quantity_logarithmic_colors,
-            figsize=figsize, title=title).make()
+            figsize=figsize, title=title, fig=fig).make()
 
         return self.plot_handle
 
@@ -1201,8 +1217,8 @@ def compute_maximal_parameter(problem_function, initial_guess=None, lambda_tol=D
         initial_guess = cur_problem.approximate(algorithm=1)
     if isinstance(initial_guess, StaticConfiguration):
         initial_guess = initial_guess._th()
-    theta_0 = initial_guess
-    out = cur_problem.compute(initial_guess=theta_0, tol=newton_tol, maxiter=newton_maxiter,
+    theta0 = initial_guess
+    out = cur_problem.compute(initial_guess=theta0, tol=newton_tol, maxiter=newton_maxiter,
                               stop_as_residual_increases=newton_stop_as_residual_increases,
                               stop_if_not_target_n=newton_stop_if_not_target_n)
     config, status, newton_iter_info = out[0], out[1], out[2]
@@ -1229,7 +1245,7 @@ def compute_maximal_parameter(problem_function, initial_guess=None, lambda_tol=D
 
         # determine solution at current lambda
         cur_problem = problem_function(lambda_val)
-        out = cur_problem.compute(initial_guess=theta_0, tol=newton_tol, maxiter=newton_maxiter,
+        out = cur_problem.compute(initial_guess=theta0, tol=newton_tol, maxiter=newton_maxiter,
                                   stop_as_residual_increases=newton_stop_as_residual_increases,
                                   stop_if_not_target_n=newton_stop_if_not_target_n)
         config, status, newton_iter_info = out[0], out[1], out[2]
@@ -1250,7 +1266,8 @@ def compute_maximal_parameter(problem_function, initial_guess=None, lambda_tol=D
             is_solution = has_converged
 
         # update information on current iteration in info handle
-        info._set(lambda_val, lambda_stepsize, has_converged, newton_iter_info, is_stable)
+        info._set(lambda_val, config if has_converged else None, lambda_stepsize,
+                  has_converged, newton_iter_info, is_stable)
 
         # determine new lambda value to try (and corresponding initial condition)
         if is_solution:
